caellion-python-commons: caellion/pycommons/codeanalysis/reports.py File Reference

caellion-python-commons

Classes | Namespaces
reports.py File Reference

Go to the source code of this file.

## Classes
class | caellion.pycommons.codeanalysis.reports.ReportBuilder
| This class provides a set of methods to create reports that are compatible with Jenkins' warnings-ng plugin. More...

## Namespaces
| caellion.pycommons.codeanalysis.reports
| This module provides utlilities related to creating Jenkins' warnings-ng-plugin-compatible reports from codeanalysis.